function [ys] = fernsRegApplyCBFS( data, ferns, inds_m, inds_n )
% Apply learned fern regressor.
%
% USAGE
%  [ys,ysCum] = fernsRegApply( data, ferns, [inds] )
%
% INPUTS
%  data     - [NxF] N length F binary feature vectors
%  ferns    - learned fern regression model
%  inds     - [NxM] cached inds (from previous call to fernsInds)
%
% OUTPUTS
%  ys       - [NxD] predicted output values
%  ysCum    - [NxM] predicted output values after each regressor
%
% EXAMPLE
%
% See also fernsRegTrain, fernsInds
%
% Piotr's Computer Vision Matlab Toolbox      Version 2.50
% Copyright 2014 Piotr Dollar.  [pdollar-at-gmail.com]
% Licensed under the Simplified BSD License [see external/bsd.txt]
N=size(data,1);
D=size(ferns.ysFern,2);
M=size(ferns.ysFern,3);
  ys=zeros(N,D); 
  for m=1:M

  
  data_diff=data(:,inds_m(:,m))-data(:,inds_n(:,m));
  inds = fernsInds(data_diff,ferns.fids(m,:),ferns.thrs(m,:));
      ys = ys + ferns.ysFern(inds,:,m); 
  end

  